# 
# This file is part of Dist-Zilla-Plugin-CheckExtraTests
# 
# This software is Copyright (c) 2010 by David Golden.
# 
# This is free software, licensed under:
# 
#   The Apache License, Version 2.0, January 2004
# 
package Foo;
our $VERSION = '0.002';
use strict;
use warnings;
# ABSTRACT: Foo this thing

1;

=head1 DESCRIPTION

Foo the foo.

=cut
